@@ -22,7 +22,7 @@ class AchievementEngine(object):
             obj.callback = construct_callback(cls)
             obj.save()
         # optional category
-        if cls.category:
+        if cls.__dict__.get('category', None):
             obj.category = cls.category
             obj.save()
         achievement_registered.send(sender=self, achievement_class=cls)
